@@ -14,6 +14,26 @@ from cmu_graphics.cmu_graphics import (
     Rect,
     RegularPolygon,
     Star,
+    drawArc,
+    drawCircle,
+    drawImage,
+    drawLabel,
+    drawLine,
+    drawOval,
+    drawPolygon,
+    drawRect,
+    drawRegularPolygon,
+    drawStar,
+    ArcShape,
+    CircleShape,
+    ImageShape,
+    LabelShape,
+    LineShape,
+    OvalShape,
+    PolygonShape,
+    RectShape,
+    RegularPolygonShape,
+    StarShape,
     Sound,
     gradient,
     rgb,
@@ -27,6 +47,10 @@ from cmu_graphics.cmu_graphics import (
     print,
     assertEqual,
     Robot,
+    runApp,
+    runAppWithScreens,
+    setActiveScreen,
+    getImageSize,
 )
 
 from cmu_graphics.utils import (
@@ -56,6 +80,8 @@ from cmu_graphics.shape_logic import (
 )
 
 __all__ = TRANSLATED_GLOBALS['keys']
+__all__.extend(['setLanguage', 'cmu_graphics', 'runApp', 'runAppWithScreens', 'setActiveScreen', 'getImageSize'])
+__all__.extend(['drawArc', 'ArcShape', 'drawCircle', 'CircleShape', 'drawImage', 'ImageShape', 'drawLabel', 'LabelShape', 'drawLine', 'LineShape', 'drawOval', 'OvalShape', 'drawPolygon', 'PolygonShape', 'drawRect', 'RectShape', 'drawRegularPolygon', 'RegularPolygonShape', 'drawStar', 'StarShape'])
 
 g = globals()
 for language in TRANSLATED_GLOBALS:
@@ -66,9 +92,6 @@ for language in TRANSLATED_GLOBALS:
                     g[accent_combination] = g[en_name]
                     __all__.append(accent_combination)
 
-__all__.append('setLanguage')
-__all__.append('cmu_graphics')
-
 for language in TRANSLATED_BOOLEANS:
     if language != 'keys':
         for (en_name, trans_name) in TRANSLATED_BOOLEANS[language].items():
