@@ -268,6 +268,10 @@ def translateKeyName(keyName, originalLanguage):
 
 def cleanAndClose():
     shape_logic.cleanSoundProcesses()
+    try:
+        app._app.callUserFn('onAppStop', (), redraw=False)
+    except:
+        pass
     os._exit(0)
 
 def _safeMethod(appMethod):
@@ -567,8 +571,6 @@ class App(object):
     def getRight(self):
         return self._width
     def setRight(self, value):
-        if not self._isMvc:
-            raise Exception('App.right is readonly')
         self._width = value
         self.onResize()
     right = property(getRight, setRight)
@@ -582,8 +584,6 @@ class App(object):
     def getBottom(self):
         return self._height
     def setBottom(self, value):
-        if not self._isMvc:
-            raise Exception('App.bottom is readonly')
         self._height = value
         self.onResize()
     bottom = property(getBottom, setBottom)
@@ -591,8 +591,6 @@ class App(object):
     def getWidth(self):
         return self._width
     def setWidth(self, value):
-        if not self._isMvc:
-            raise Exception('App.width is readonly')
         self._width = value
         self.onResize()
     width = property(getWidth, setWidth)
@@ -600,8 +598,6 @@ class App(object):
     def getHeight(self):
         return self._height
     def setHeight(self, value):
-        if not self._isMvc:
-            raise Exception('App.height is readonly')
         self._height = value
         self.onResize()
     height = property(getHeight, setHeight)
@@ -784,7 +780,7 @@ Otherwise, please call cmu_graphics.run() in place of runApp.
 
     app._app.callUserFn('onAppStart', (), kwargs, redraw=False)
     if app._app._ranWithScreens:
-        app._app.callUserFn(f'{app._app.activeScreen}_onScreenActivated', ())
+        app._app.callUserFn(f'{app._app.activeScreen}_onScreenActivate', ())
     app._app.redrawAllWrapper() # Draw even if there are no events
 
     run()
@@ -799,14 +795,14 @@ def setActiveScreen(screen, suppressEvent=False):
         raise Exception(f'Screen {screen} requires {redrawAllFnName}()')
     app._app.activeScreen = screen
     if not suppressEvent:
-        app._app.callUserFn(f'{screen}_onScreenActivated', ())
+        app._app.callUserFn(f'{screen}_onScreenActivate', ())
 
 def runAppWithScreens(initialScreen, *args, **kwargs):
     userGlobals = app._app.userGlobals
 
     def checkForAppFns():
         for appFnName in APP_FN_NAMES:
-            if appFnName in userGlobals:
+            if appFnName != 'onAppStart' and appFnName in userGlobals:
                 raise Exception(f'Do not define {appFnName} when using screens')
 
     def getScreenFnNames(appFnName):
@@ -819,8 +815,11 @@ def runAppWithScreens(initialScreen, *args, **kwargs):
 
     def makeAppFnWrapper(appFnName):
         if appFnName == 'onAppStart':
+            origOnAppStart = userGlobals.get('onAppStart')
             def onAppStartWrapper(app):
-                for screenFnName in getScreenFnNames('onScreenStart'):
+                if origOnAppStart:
+                    origOnAppStart(app)
+                for screenFnName in sorted(getScreenFnNames('onAppStart')):
                     screenFn = userGlobals[screenFnName]
                     screenFn(app)
             return onAppStartWrapper
@@ -908,7 +907,7 @@ def loop():
 
 def run():
     if not app._app._isMvc:
-        for cs3ModeHandler in ('onAppStart', 'redrawAll'):
+        for cs3ModeHandler in ['redrawAll']:
             if cs3ModeHandler in __main__.__dict__:
                 raise Exception(f"You defined the event handler {cs3ModeHandler} which works with CS3 mode, and then called cmu_graphics.run(), which doesn't work with CS3 mode. Did you mean to call runApp instead?")
 
